@@ -1,9 +1,7 @@
-# arithmetic.py
 # __init__.py
 from .thres import thres
 from .cond import cond
 from .equa import equa
-from .divide import divide
 
 
 
